/*
 * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
 * Copyright (C) $$Year-Rel$$ The Jalview Authors
 * 
 * This file is part of Jalview.
 * 
 * Jalview is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *  
 * Jalview is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty 
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 * PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
 * The Jalview Authors are detailed in the 'AUTHORS' file.
 */
package jalview.datamodel;

/**
 * Defines internal constants for unambiguous annotation of DbRefEntry source
 * strings and describing the data retrieved from external database sources (see
 * jalview.ws.DbSourcProxy) <br/>
 * TODO: replace with ontology to allow recognition of particular attributes
 * (e.g. protein coding, alignment (ortholog db, paralog db, domain db),
 * genomic, transcriptomic, 3D structure providing (PDB, MODBASE, etc) ..).
 * 
 * @author JimP
 * 
 */
public class DBRefSource
{
  /**
   * UNIPROT Accession Number
   */
  public static String UNIPROT = "UNIPROT";

  /**
   * UNIPROT Entry Name
   */
  public static String UP_NAME = "UNIPROT_NAME".toUpperCase();

  /**
   * Uniprot Knowledgebase/TrEMBL as served from EMBL protein products.
   */
  public static final String UNIPROTKB = "UniProtKB/TrEMBL".toUpperCase();

  public static final String EMBLCDSProduct = "EMBLCDSProtein"
          .toUpperCase();

  /**
   * PDB Entry Code
   */
  public static String PDB = "PDB";

  /**
   * mmCIF Entry Code
   */
  public static String MMCIF = "mmCIF";

  /**
   * EMBL ID
   */
  public static String EMBL = "EMBL";

  /**
   * EMBLCDS ID
   */
  public static String EMBLCDS = "EMBLCDS";

  /**
   * PFAM ID
   */
  public static String PFAM = "PFAM";

  /**
   * RFAM ID
   */
  public static String RFAM = "RFAM";

  /**
   * GeneDB ID
   */
  public static final String GENEDB = "GeneDB".toUpperCase();

  /**
   * Ensembl
   */
  public static final String ENSEMBL = "ENSEMBL";

  public static final String ENSEMBLGENOMES = "ENSEMBLGENOMES";

  /**
   * List of databases whose sequences might have coding regions annotated
   */
  public static final String[] DNACODINGDBS = { EMBL, EMBLCDS, GENEDB,
      ENSEMBL };

  public static final String[] CODINGDBS = { EMBLCDS, GENEDB, ENSEMBL };

  public static final String[] PROTEINDBS = { UNIPROT, PDB, UNIPROTKB,
      EMBLCDSProduct, ENSEMBL }; // Ensembl ENSP* entries are protein
}
